==> modonomicon-1.20.1-fabric-1.79.1-sources.jar: com/klikli_dev/modonomicon/api/stub/multiblock/StubMultiblock.java <==
/*
 * SPDX-FileCopyrightText: 2022 Authors of Patchouli
 *
 * SPDX-License-Identifier: MIT
 */
package com.klikli_dev.modonomicon.api.stub.multiblock;

import com.klikli_dev.modonomicon.api.ModonomiconAPI;
import com.klikli_dev.modonomicon.api.multiblock.Multiblock;
import com.mojang.datafixers.util.Pair;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2382;
import net.minecraft.class_2470;
import net.minecraft.class_2540;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_6539;

public class StubMultiblock implements Multiblock {

    public static final class_2960 TYPE = new class_2960(ModonomiconAPI.ID + ":stub");

    public static final StubMultiblock INSTANCE = new StubMultiblock();

    private StubMultiblock() {
    }

    @Override
    public class_2960 getType() {
        return TYPE;
    }

    @Override
    public void setLevel(class_1937 level) {

    }

    @Override
    public Multiblock offset(int x, int y, int z) {
        return this;
    }

    @Override
    public Multiblock offsetView(int x, int y, int z) {
        return this;
    }

    @Override
    public Multiblock setSymmetrical(boolean symmetrical) {
        return this;
    }

    @Override
    public Multiblock setId(class_2960 res) {
        return this;
    }

    @Override
    public boolean isSymmetrical() {
        return false;
    }

    @Override
    public class_2960 getId() {
        return new class_2960(ModonomiconAPI.ID, "stub");
    }

    @Override
    public void place(class_1937 world, class_2338 pos, class_2470 rotation) {
        // NO-OP
    }

    @Override
    public Pair<class_2338, Collection<SimulateResult>> simulate(class_1937 world, class_2338 anchor, class_2470 rotation, boolean forView, boolean disableOffset) {
        return Pair.of(class_2338.field_10980, Collections.emptyList());
    }

    @Override
    public class_2470 validate(class_1937 world, class_2338 pos) {
        return null;
    }

    @Override
    public boolean validate(class_1937 world, class_2338 pos, class_2470 rotation) {
        return false;
    }

    @Override
    public boolean test(class_1937 world, class_2338 start, int x, int y, int z, class_2470 rotation) {
        return false;
    }

    @Override
    public class_2382 getSize() {
        return class_2382.field_11176;
    }

    @Override
    public class_2382 getOffset() {
        return class_2382.field_11176;
    }

    @Override
    public class_2382 getViewOffset() {
        return class_2382.field_11176;
    }

    @Override
    public void toNetwork(class_2540 buffer) {

    }

    @Override
    public float method_24852(class_2350 direction, boolean shade) {
        return 0;
    }

    @Override
    public class_3568 method_22336() {
        return null;
    }

    @Override
    public int method_23752(class_2338 blockPos, class_6539 colorResolver) {
        return 0;
    }

    @Nullable
    @Override
    public class_2586 method_8321(class_2338 pos) {
        return null;
    }

    @Override
    public class_2680 method_8320(class_2338 pos) {
        return null;
    }

    @Override
    public class_3610 method_8316(class_2338 pos) {
        return null;
    }

    @Override
    public int method_31605() {
        return 0;
    }

    @Override
    public int method_31607() {
        return 0;
    }
}

==> modonomicon-1.21.8-fabric-1.117.1-sources.jar: com/klikli_dev/modonomicon/api/stub/multiblock/StubMultiblock.java <==
/*
 * SPDX-FileCopyrightText: 2022 Authors of Patchouli
 *
 * SPDX-License-Identifier: MIT
 */
package com.klikli_dev.modonomicon.api.stub.multiblock;

import com.klikli_dev.modonomicon.api.ModonomiconAPI;
import com.klikli_dev.modonomicon.api.multiblock.Multiblock;
import com.mojang.datafixers.util.Pair;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2382;
import net.minecraft.class_2470;
import net.minecraft.class_2540;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_6539;

public class StubMultiblock implements Multiblock {

    public static final class_2960 TYPE = class_2960.method_60654(ModonomiconAPI.ID + ":stub");

    public static final StubMultiblock INSTANCE = new StubMultiblock();

    private StubMultiblock() {
    }

    @Override
    public class_2960 getType() {
        return TYPE;
    }

    @Override
    public void setLevel(class_1937 level) {

    }

    @Override
    public Multiblock offset(int x, int y, int z) {
        return this;
    }

    @Override
    public Multiblock offsetView(int x, int y, int z) {
        return this;
    }

    @Override
    public Multiblock setSymmetrical(boolean symmetrical) {
        return this;
    }

    @Override
    public Multiblock setId(class_2960 res) {
        return this;
    }

    @Override
    public boolean isSymmetrical() {
        return false;
    }

    @Override
    public class_2960 getId() {
        return class_2960.method_60655(ModonomiconAPI.ID, "stub");
    }

    @Override
    public void place(class_1937 world, class_2338 pos, class_2470 rotation) {
        // NO-OP
    }

    @Override
    public Pair<class_2338, Collection<SimulateResult>> simulate(class_1937 world, class_2338 anchor, class_2470 rotation, boolean forView, boolean disableOffset) {
        return Pair.of(class_2338.field_10980, Collections.emptyList());
    }

    @Override
    public class_2470 validate(class_1937 world, class_2338 pos) {
        return null;
    }

    @Override
    public boolean validate(class_1937 world, class_2338 pos, class_2470 rotation) {
        return false;
    }

    @Override
    public boolean test(class_1937 world, class_2338 start, int x, int y, int z, class_2470 rotation) {
        return false;
    }

    @Override
    public class_2382 getSize() {
        return class_2382.field_11176;
    }

    @Override
    public class_2382 getOffset() {
        return class_2382.field_11176;
    }

    @Override
    public class_2382 getViewOffset() {
        return class_2382.field_11176;
    }

    @Override
    public void toNetwork(class_2540 buffer) {

    }

    @Override
    public float method_24852(class_2350 direction, boolean shade) {
        return 0;
    }

    @Override
    public class_3568 method_22336() {
        return null;
    }

    @Override
    public int method_23752(class_2338 blockPos, class_6539 colorResolver) {
        return 0;
    }

    @Nullable
    @Override
    public class_2586 method_8321(class_2338 pos) {
        return null;
    }

    @Override
    public class_2680 method_8320(class_2338 pos) {
        return null;
    }

    @Override
    public class_3610 method_8316(class_2338 pos) {
        return null;
    }

    @Override
    public int method_31605() {
        return 0;
    }

    @Override
    public int method_31607() {
        return 0;
    }
}
